==> kpopup-0.5.0.tar.gz: kpopup-0.5.0/kpopup/misc.cpp <==
/***************************************************************************
                          misc.cpp  -  description
                          ------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <malloc.h>
#include <stdio.h>
#include <stdlib.h>

char *File_read(const char *Filename, int ZLaenge)
{
 char *PopupText = NULL;
 char Command[50];
 FILE *File;
 int i = 0;
 int linel = 0;

 if((File = fopen(Filename, "r")) != 0)
   {
    while(!feof(File))
     {
      if(PopupText == NULL) PopupText = (char *) malloc (sizeof(char));
       else PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);
      PopupText[i] = fgetc(File);
      if(PopupText[i] == '\n') linel = 0; else linel++;
  	  if(linel == ZLaenge)
        {
	       PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);	
         PopupText[++i] = '\n';
  	     linel = 0;
        }
      i++;
     }

    if(PopupText == NULL) PopupText = (char *) malloc (sizeof(char));
     else PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);
    PopupText[i - 1] = 0;
    fclose(File);

    sprintf(Command, "rm -f %s", Filename);
    system(Command);
   }
  else
   {
    printf("Fileerror!\n");
   }

 return(PopupText);
}

==> kpopup-0.7.1.tar.gz: kpopup-0.7.1/kpopup/misc.cpp <==
/***************************************************************************
                          misc.cpp  -  description
                          ------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <malloc.h>
#include <stdio.h>
#include <stdlib.h>

char *File_read(const char *Filename)
{
 char *PopupText = NULL;
 char Command[50];
 FILE *File;
 int i = 0;

 if((File = fopen(Filename, "r")) != 0)
   {
    while(!feof(File))
     {
      if(PopupText == NULL) PopupText = (char *) malloc (sizeof(char));
       else PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);
      PopupText[i] = fgetc(File);
      i++;
     }

    if(PopupText == NULL) PopupText = (char *) malloc (sizeof(char));
     else PopupText = (char *) realloc (PopupText, sizeof(char) * i + 1);
    PopupText[i - 1] = 0;
    fclose(File);

    sprintf(Command, "rm -f %s", Filename);
    system(Command);
   }
  else
   {
    printf("Fileerror!\n");
   }
 return(PopupText);
}
